@@ -1,8 +1,10 @@
+import tkinter.messagebox as mb
 import tkinter.simpledialog as sd
 
 import cv2
 import matplotlib.pyplot as plt
 import numpy as np
+import pymedphys
 from matplotlib.backends.backend_agg import FigureCanvasAgg
 from matplotlib.figure import Figure
 from matplotlib.ticker import AutoMinorLocator
@@ -578,6 +580,8 @@ class DoseFigureHandler:
         except:
             pass
 
+        self.set_xlims()
+
         if self.zoom == True:
 
             self.canvas.draw()
@@ -585,9 +589,11 @@ class DoseFigureHandler:
             self.inverted_transform = self.ax.transData.inverted()
             width, height = self.fig.canvas.get_width_height()
 
-            self.focuspoint = self.plots[-1].axis[self.half][
-                len(self.plots[-1].axis[self.half]) // 2
-            ]
+            extent = max([max(plot.axis[self.half]) for plot in self.plots])
+            reference = [
+                plot for plot in self.plots if max(plot.axis[self.half]) == extent
+            ][-1]
+
             try:
                 self.focuspoint = self.inverted_transform.transform(
                     (
@@ -605,26 +611,28 @@ class DoseFigureHandler:
                         1,
                     )
                 )
-                self.focuspoint = self.plots[-1].axis[self.half][
+                self.focuspoint = reference.axis[self.half][
                     np.abs(
-                        np.asarray(self.plots[-1].axis[self.half] - self.focuspoint[0])
+                        np.asarray(reference.axis[self.half] - self.focuspoint[0])
                     ).argmin()
                 ]
             except AttributeError:
-                pass
+                self.focuspoint = reference.axis[self.half][
+                    len(reference.axis[self.half]) // 2
+                ]
             except IndexError:
-                pass
+                self.focuspoint = reference.axis[self.half][
+                    len(reference.axis[self.half]) // 2
+                ]
 
-            pixels = self.transform.transform(np.vstack([plot_data[0], plot_data[2]]).T)
+            pixels = self.transform.transform(
+                np.vstack([reference.axis[self.half], reference.dose[self.half]]).T
+            )
             x, y = pixels.T
             y = height - y
 
-            self.pixelx = (
-                x[self.plots[-1].axis[self.half].index(self.focuspoint)] / width
-            )
-            self.pixely = (
-                y[self.plots[-1].axis[self.half].index(self.focuspoint)] / height
-            )
+            self.pixelx = x[reference.axis[self.half].index(self.focuspoint)] / width
+            self.pixely = y[reference.axis[self.half].index(self.focuspoint)] / height
 
             loc = "lower left"
             if self.half == False and self.plots[0].direction != "Z":
@@ -722,8 +730,6 @@ class DoseFigureHandler:
 
             mark_inset(self.ax, self.axins, loc1=loc1, loc2=loc2, fc="none", ec="0.5")
 
-        self.set_xlims()
-
         return
 
     def set_xlims(self):
@@ -742,6 +748,26 @@ class DoseFigureHandler:
 
         self.ax.set_xlim(self.current_limits)
 
+    def gamma(self):
+
+        gamma = pymedphys.gamma(
+            (self.data[0][0],),
+            self.data[0][2],
+            (self.data[1][0],),
+            self.data[1][2],
+            self.parent.gammathreshold,
+            self.parent.gammadist,
+            quiet=True,
+        )
+
+        valid_gamma = gamma[~np.isnan(gamma)]
+        pass_ratio = np.sum(valid_gamma <= 1) / len(valid_gamma)
+
+        mb.showinfo(
+            "Gamma-Index",
+            f"ɣ ({self.parent.gammaacc.get()}) = {round(pass_ratio,4)}\n∅ = {round(np.average(valid_gamma),4)}",
+        )
+
     def return_figure(self, filenames):
 
         """Passes the image of the plot and the plot type to the MainApplication
