@@ -1,6 +1,7 @@
 import os
 import time
 import tkinter as tk
+from pathlib import Path
 from tkinter import filedialog as fd
 from tkinter import simpledialog as sd
 from tkinter.colorchooser import askcolor
@@ -11,6 +12,7 @@ from PIL import Image, ImageTk
 from ..resources.info import show_info
 from ..resources.language import Text
 from .dose_figure_handler import DoseFigureHandler
+from .gamma import ChangeGamma
 from .nameandstyle import GraphNameAndStyle
 from .profile import ProfileHandler
 from .recent_files import RecentFileManager
@@ -408,7 +410,23 @@ class MainApplication(tk.Frame):
             variable=self.diffplot,
         )
 
-        self.normmenu.entryconfig(13, state=tk.DISABLED)
+        self.gammamenu = tk.Menu(self.menubar, tearoff=False)
+        self.gammaacc = tk.StringVar()
+        self.gammadist = 2
+        self.gammathreshold = 2
+        self.gammaacc.set(f"{self.gammathreshold}%/{self.gammadist}mm")
+        self.gammamenu.add_command(
+            label=self.text.calculate[self.lang], command=self.gamma
+        )
+        self.gammamenu.add_command(
+            label=self.text.gamma[self.lang],
+            accelerator=self.gammaacc.get(),
+            command=self.changegamma,
+        )
+
+        self.normmenu.add_cascade(
+            label=self.text.gammamenu[self.lang], menu=self.gammamenu
+        )
 
         self.errlimmenu = tk.Menu(self.menubar, tearoff=False)
         self.errlimmenu.add_command(
@@ -454,7 +472,10 @@ class MainApplication(tk.Frame):
         self.normmenu.add_cascade(
             label=Text().errlimmenu[self.lang], menu=self.errlimmenu
         )
+
+        self.normmenu.entryconfig(13, state=tk.DISABLED)
         self.normmenu.entryconfig(14, state=tk.DISABLED)
+        self.normmenu.entryconfig(15, state=tk.DISABLED)
 
         self.menubar.add_command(label=self.text.about[self.lang], command=self.about)
 
@@ -644,8 +665,17 @@ class MainApplication(tk.Frame):
             filetypes = [(self.text.measurementdata[self.lang], ["txt", ".csv"])]
         elif type == "ptw":
             filetypes = [(self.text.ptw[self.lang], ".mcc")]
+
+        try:
+            initialdir = os.path.dirname(
+                self.profile.get_attribute("recent_files")[0][0]
+            )
+            print(initialdir)
+        except IndexError:
+            initialdir = Path.home()
+
         self.current_file = fd.askopenfilenames(
-            initialdir=os.getcwd(), filetypes=filetypes
+            initialdir=initialdir, filetypes=filetypes
         )
 
         if self.current_file == "" or self.current_file == ():
@@ -662,6 +692,8 @@ class MainApplication(tk.Frame):
         self.filemenu.entryconfig(5, state=tk.NORMAL)
         if len(self.filenames) > 2:
             self.normmenu.entryconfig(13, state=tk.DISABLED)
+            self.normmenu.entryconfig(14, state=tk.DISABLED)
+            self.normmenu.entryconfig(15, state=tk.DISABLED)
         self.saved = False
 
         return
@@ -722,6 +754,8 @@ class MainApplication(tk.Frame):
         self.filemenu.entryconfig(5, state=tk.NORMAL)
         if len(self.filenames) > 2:
             self.normmenu.entryconfig(13, state=tk.DISABLED)
+            self.normmenu.entryconfig(14, state=tk.DISABLED)
+            self.normmenu.entryconfig(15, state=tk.DISABLED)
         self.saved = False
 
     def close_file(self, event=None):
@@ -737,6 +771,7 @@ class MainApplication(tk.Frame):
         self.addmeasuremenu.entryconfig(1, state=tk.NORMAL)
         self.normmenu.entryconfig(13, state=tk.DISABLED)
         self.normmenu.entryconfig(14, state=tk.DISABLED)
+        self.normmenu.entryconfig(15, state=tk.DISABLED)
         self.parammenu.entryconfig(0, state=tk.NORMAL)
         self.menubar.delete(4, 5)
         self.filenames = []
@@ -897,6 +932,8 @@ class MainApplication(tk.Frame):
             self.diffplot.set(False)
             self.DoseFigureHandler.diffplot = False
             self.normmenu.entryconfig(13, state=tk.DISABLED)
+            self.normmenu.entryconfig(14, state=tk.DISABLED)
+            self.normmenu.entryconfig(15, state=tk.DISABLED)
 
         if self.filenames[-1][0].endswith(".mcc") == True:
             self.filenames.pop(-1)
@@ -1081,9 +1118,13 @@ class MainApplication(tk.Frame):
 
         if len(self.DoseFigureHandler.plots) >= 2:
             self.normmenu.entryconfig(13, state=tk.DISABLED)
+            self.normmenu.entryconfig(14, state=tk.DISABLED)
+            self.normmenu.entryconfig(15, state=tk.DISABLED)
 
         if len(self.DoseFigureHandler.plots) == 2:
             self.normmenu.entryconfig(13, state=tk.NORMAL)
+            self.normmenu.entryconfig(14, state=tk.NORMAL)
+            self.normmenu.entryconfig(15, state=tk.NORMAL)
 
         if len(self.DoseFigureHandler.plots) > 5:
             self.parammenu.entryconfig(0, state=tk.DISABLED)
@@ -1232,6 +1273,14 @@ class MainApplication(tk.Frame):
             self.tablevar.set(False)
             sd.messagebox.showwarning("", self.text.calcfail[self.lang])
 
+    def gamma(self):
+
+        self.DoseFigureHandler.gamma()
+
+    def changegamma(self):
+
+        Gamma = ChangeGamma(self)
+
     def new_zoom(self, event):
 
         if self.zoom.get() == True:
@@ -1416,8 +1465,8 @@ class MainApplication(tk.Frame):
                         coords[0]
                         + imdims[0]
                         * (
-                            0.44
-                            - 0.0085
+                            0.438
+                            - 0.0082
                             * max(
                                 map(
                                     len,
@@ -1430,17 +1479,17 @@ class MainApplication(tk.Frame):
                         ),
                         (
                             (canvdims[1] - imdims[1]) // 2
-                            + imdims[1] * (0.015 + i * 0.04 + normdiff)
+                            + imdims[1] * (0.02 + i * 0.0347 + normdiff)
                         )
                         * factor,
-                        coords[0] + imdims[0] * 0.49,
+                        coords[0] + imdims[0] * 0.488,
                         (
                             (canvdims[1] - imdims[1]) // 2
-                            + imdims[1] * (0.055 + i * 0.04 + normdiff)
+                            + imdims[1] * (0.0547 + i * 0.0347 + normdiff)
                         )
                         * factor,
                         fill="",
-                        outline="black",
+                        outline="",
                         tags="rename",
                     )
                 ]
@@ -1540,7 +1589,6 @@ class MainApplication(tk.Frame):
 
                                 self.show_preview()
                             return
-
                         dialog = GraphNameAndStyle(self, index)
                         self.parent.wait_window(dialog.top)
 
