@@ -1,6 +1,5 @@
 import tkinter as tk
 import tkinter.ttk as ttk
-from tkinter import ttk
 
 from ..resources.language import Text
 
@@ -12,6 +11,8 @@ class GraphNameAndStyle:
         self.index = index
 
         self.top = tk.Toplevel()
+        if self.index >= len(self.parent.DoseFigureHandler.plots):
+            self.top.destroy()
         self.geometry = [
             self.parent.parent.winfo_rootx(),
             self.parent.parent.winfo_rooty(),
@@ -72,6 +73,7 @@ class GraphNameAndStyle:
                 xlabel = self.parent.DoseFigureHandler.xlabel
             self.enterbox.insert(tk.END, string=xlabel)
 
+        self.enterbox.focus()
         self.lift()
 
     def lift(self):
